@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 1998, 1999, 2000, 2008, 2010 Sergey Poznyakoff
+   Copyright (C) 1998-2016 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@ dicod_xversion(dico_stream_t str, int argc, char **argv)
 {
     stream_writez(str, "110 ");
     stream_writez(str, (char*)program_version);
-    dico_stream_write(str, "\r\n", 2);
+    dico_stream_write(str, "\n", 1);
 }
     
 void
