@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 2.5.1.  */
+/* A Bison parser, made by GNU Bison 2.7.  */
 
 /* Bison implementation for Yacc-like parsers in C
    
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.5.1"
+#define YYBISON_VERSION "2.7"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -58,14 +58,11 @@
 /* Pull parsers.  */
 #define YYPULL 1
 
-/* Using locations.  */
-#define YYLSP_NEEDED 1
 
 
 
 /* Copy the first part of user declarations.  */
-
-/* Line 268 of yacc.c  */
+/* Line 371 of yacc.c  */
 #line 1 "json-gram.y"
 
 /* This file is part of Grecs.
@@ -116,9 +113,8 @@ objfree(void *ptr)
 }
 
 
-
-/* Line 268 of yacc.c  */
-#line 122 "json-gram.c"
+/* Line 371 of yacc.c  */
+#line 118 "json-gram.c"
 
 # ifndef YY_NULL
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -128,11 +124,6 @@ objfree(void *ptr)
 #  endif
 # endif
 
-/* Enabling traces.  */
-#ifndef YYDEBUG
-# define YYDEBUG 1
-#endif
-
 /* Enabling verbose error messages.  */
 #ifdef YYERROR_VERBOSE
 # undef YYERROR_VERBOSE
@@ -141,11 +132,17 @@ objfree(void *ptr)
 # define YYERROR_VERBOSE 1
 #endif
 
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
+/* In a future release of Bison, this section will be replaced
+   by #include "y.tab.h".  */
+#ifndef YY_YY_JSON_GRAM_H_INCLUDED
+# define YY_YY_JSON_GRAM_H_INCLUDED
+/* Enabling traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 1
+#endif
+#if YYDEBUG
+extern int grecs_json_debug;
 #endif
-
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -169,12 +166,10 @@ objfree(void *ptr)
 
 
 
-
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
 {
-
-/* Line 295 of yacc.c  */
+/* Line 387 of yacc.c  */
 #line 64 "json-gram.y"
 
 	int b;
@@ -186,9 +181,8 @@ typedef union YYSTYPE
 	struct json_pair *p;
 
 
-
-/* Line 295 of yacc.c  */
-#line 192 "json-gram.c"
+/* Line 387 of yacc.c  */
+#line 186 "json-gram.c"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define grecs_json_stype YYSTYPE /* obsolescent; will be withdrawn */
@@ -208,12 +202,28 @@ typedef struct YYLTYPE
 # define YYLTYPE_IS_TRIVIAL 1
 #endif
 
+extern YYSTYPE grecs_json_lval;
+extern YYLTYPE grecs_json_lloc;
+#ifdef YYPARSE_PARAM
+#if defined __STDC__ || defined __cplusplus
+int grecs_json_parse (void *YYPARSE_PARAM);
+#else
+int grecs_json_parse ();
+#endif
+#else /* ! YYPARSE_PARAM */
+#if defined __STDC__ || defined __cplusplus
+int grecs_json_parse (void);
+#else
+int grecs_json_parse ();
+#endif
+#endif /* ! YYPARSE_PARAM */
+
+#endif /* !YY_YY_JSON_GRAM_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-
-/* Line 345 of yacc.c  */
-#line 217 "json-gram.c"
+/* Line 390 of yacc.c  */
+#line 227 "json-gram.c"
 
 #ifdef short
 # undef short
@@ -266,24 +276,24 @@ typedef short int grecs_json_type_int16;
 # if defined YYENABLE_NLS && YYENABLE_NLS
 #  if ENABLE_NLS
 #   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
-#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
 #  endif
 # endif
 # ifndef YY_
-#  define YY_(msgid) msgid
+#  define YY_(Msgid) Msgid
 # endif
 #endif
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YYUSE(e) ((void) (e))
+# define YYUSE(E) ((void) (E))
 #else
-# define YYUSE(e) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 /* Identity function, used to suppress warnings about constant conditions.  */
 #ifndef lint
-# define YYID(n) (n)
+# define YYID(N) (N)
 #else
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
@@ -512,7 +522,7 @@ static const grecs_json_type_uint8 grecs_json_rline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+#if YYDEBUG || YYERROR_VERBOSE || 1
 /* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const grecs_json_tname[] =
@@ -590,10 +600,10 @@ static const grecs_json_type_uint8 grecs_json_table[] =
       20,    26,     0,    23,    22,    24,    25,    21
 };
 
-#define grecs_json_pact_value_is_default(grecs_json_state) \
-  ((grecs_json_state) == (-13))
+#define grecs_json_pact_value_is_default(Yystate) \
+  (!!((Yystate) == (-13)))
 
-#define grecs_json_table_value_is_error(grecs_json_table_value) \
+#define grecs_json_table_value_is_error(Yytable_value) \
   YYID (0)
 
 static const grecs_json_type_int8 grecs_json_check[] =
@@ -655,7 +665,7 @@ do                                                              \
     }								\
 while (YYID (0))
 
-
+/* Error token number */
 #define YYTERROR	1
 #define YYERRCODE	256
 
@@ -664,27 +674,28 @@ while (YYID (0))
    If N is 0, then set CURRENT to the empty location which ends
    the previous symbol: RHS[0] (always defined).  */
 
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (YYID (N))                                                    \
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
+# define YYLLOC_DEFAULT(Current, Rhs, N)                                \
+    do                                                                  \
+      if (YYID (N))                                                     \
+        {                                                               \
+          (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;        \
+          (Current).first_column = YYRHSLOC (Rhs, 1).first_column;      \
+          (Current).last_line    = YYRHSLOC (Rhs, N).last_line;         \
+          (Current).last_column  = YYRHSLOC (Rhs, N).last_column;       \
+        }                                                               \
+      else                                                              \
+        {                                                               \
+          (Current).first_line   = (Current).last_line   =              \
+            YYRHSLOC (Rhs, 0).last_line;                                \
+          (Current).first_column = (Current).last_column =              \
+            YYRHSLOC (Rhs, 0).last_column;                              \
+        }                                                               \
     while (YYID (0))
 #endif
 
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
+
 
 /* YY_LOCATION_PRINT -- Print the location on the stream.
    This macro was not mandated originally: define only if we know
@@ -692,10 +703,46 @@ while (YYID (0))
 
 #ifndef YY_LOCATION_PRINT
 # if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
-#  define YY_LOCATION_PRINT(File, Loc)			\
-     fprintf (File, "%d.%d-%d.%d",			\
-	      (Loc).first_line, (Loc).first_column,	\
-	      (Loc).last_line,  (Loc).last_column)
+
+/* Print *YYLOCP on YYO.  Private, do not rely on its existence. */
+
+__attribute__((__unused__))
+#if (defined __STDC__ || defined __C99__FUNC__ \
+     || defined __cplusplus || defined _MSC_VER)
+static unsigned
+grecs_json__location_print_ (FILE *grecs_json_o, YYLTYPE const * const grecs_json_locp)
+#else
+static unsigned
+grecs_json__location_print_ (grecs_json_o, grecs_json_locp)
+    FILE *grecs_json_o;
+    YYLTYPE const * const grecs_json_locp;
+#endif
+{
+  unsigned res = 0;
+  int end_col = 0 != grecs_json_locp->last_column ? grecs_json_locp->last_column - 1 : 0;
+  if (0 <= grecs_json_locp->first_line)
+    {
+      res += fprintf (grecs_json_o, "%d", grecs_json_locp->first_line);
+      if (0 <= grecs_json_locp->first_column)
+        res += fprintf (grecs_json_o, ".%d", grecs_json_locp->first_column);
+    }
+  if (0 <= grecs_json_locp->last_line)
+    {
+      if (grecs_json_locp->first_line < grecs_json_locp->last_line)
+        {
+          res += fprintf (grecs_json_o, "-%d", grecs_json_locp->last_line);
+          if (0 <= end_col)
+            res += fprintf (grecs_json_o, ".%d", end_col);
+        }
+      else if (0 <= end_col && grecs_json_locp->first_column < end_col)
+        res += fprintf (grecs_json_o, "-%d", end_col);
+    }
+  return res;
+ }
+
+#  define YY_LOCATION_PRINT(File, Loc)          \
+  grecs_json__location_print_ (File, &(Loc))
+
 # else
 #  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
 # endif
@@ -703,7 +750,6 @@ while (YYID (0))
 
 
 /* YYLEX -- calling `grecs_json_lex' with the right arguments.  */
-
 #ifdef YYLEX_PARAM
 # define YYLEX grecs_json_lex (YYLEX_PARAM)
 #else
@@ -768,7 +814,7 @@ grecs_json__symbol_value_print (grecs_json_output, grecs_json_type, grecs_json_v
   switch (grecs_json_type)
     {
       default:
-	break;
+        break;
     }
 }
 
@@ -1014,7 +1060,6 @@ grecs_json_syntax_error (YYSIZE_T *grecs_json_msg_alloc, char **grecs_json_msg,
 {
   YYSIZE_T grecs_json_size0 = grecs_json_tnamerr (YY_NULL, grecs_json_tname[grecs_json_token]);
   YYSIZE_T grecs_json_size = grecs_json_size0;
-  YYSIZE_T grecs_json_size1;
   enum { YYERROR_VERBOSE_ARGS_MAXIMUM = 5 };
   /* Internationalized format string. */
   const char *grecs_json_format = YY_NULL;
@@ -1077,11 +1122,13 @@ grecs_json_syntax_error (YYSIZE_T *grecs_json_msg_alloc, char **grecs_json_msg,
                     break;
                   }
                 grecs_json_arg[grecs_json_count++] = grecs_json_tname[grecs_json_x];
-                grecs_json_size1 = grecs_json_size + grecs_json_tnamerr (YY_NULL, grecs_json_tname[grecs_json_x]);
-                if (! (grecs_json_size <= grecs_json_size1
-                       && grecs_json_size1 <= YYSTACK_ALLOC_MAXIMUM))
-                  return 2;
-                grecs_json_size = grecs_json_size1;
+                {
+                  YYSIZE_T grecs_json_size1 = grecs_json_size + grecs_json_tnamerr (YY_NULL, grecs_json_tname[grecs_json_x]);
+                  if (! (grecs_json_size <= grecs_json_size1
+                         && grecs_json_size1 <= YYSTACK_ALLOC_MAXIMUM))
+                    return 2;
+                  grecs_json_size = grecs_json_size1;
+                }
               }
         }
     }
@@ -1101,10 +1148,12 @@ grecs_json_syntax_error (YYSIZE_T *grecs_json_msg_alloc, char **grecs_json_msg,
 # undef YYCASE_
     }
 
-  grecs_json_size1 = grecs_json_size + grecs_json_strlen (grecs_json_format);
-  if (! (grecs_json_size <= grecs_json_size1 && grecs_json_size1 <= YYSTACK_ALLOC_MAXIMUM))
-    return 2;
-  grecs_json_size = grecs_json_size1;
+  {
+    YYSIZE_T grecs_json_size1 = grecs_json_size + grecs_json_strlen (grecs_json_format);
+    if (! (grecs_json_size <= grecs_json_size1 && grecs_json_size1 <= YYSTACK_ALLOC_MAXIMUM))
+      return 2;
+    grecs_json_size = grecs_json_size1;
+  }
 
   if (*grecs_json_msg_alloc < grecs_json_size)
     {
@@ -1166,35 +1215,35 @@ grecs_json_destruct (grecs_json_msg, grecs_json_type, grecs_json_valuep, grecs_j
     {
 
       default:
-	break;
+        break;
     }
 }
 
 
-/* Prevent warnings from -Wmissing-prototypes.  */
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int grecs_json_parse (void *YYPARSE_PARAM);
-#else
-int grecs_json_parse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
-int grecs_json_parse (void);
-#else
-int grecs_json_parse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 
 /* The lookahead symbol.  */
 int grecs_json_char;
 
+
+#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
+# define YY_IGNORE_MAYBE_UNINITIALIZED_END
+#endif
+#ifndef YY_INITIAL_VALUE
+# define YY_INITIAL_VALUE(Value) /* Nothing. */
+#endif
+
 /* The semantic value of the lookahead symbol.  */
-YYSTYPE grecs_json_lval;
+YYSTYPE grecs_json_lval YY_INITIAL_VALUE(grecs_json_val_default);
 
 /* Location data for the lookahead symbol.  */
-YYLTYPE grecs_json_lloc;
+YYLTYPE grecs_json_lloc
+# if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
+  = { 1, 1, 1, 1 }
+# endif
+;
+
 
 /* Number of syntax errors so far.  */
 int grecs_json_nerrs;
@@ -1261,7 +1310,7 @@ grecs_json_parse ()
   int grecs_json_n;
   int grecs_json_result;
   /* Lookahead token as an internal (translated) token number.  */
-  int grecs_json_token;
+  int grecs_json_token = 0;
   /* The variables used to return semantic value and location from the
      action routines.  */
   YYSTYPE grecs_json_val;
@@ -1280,10 +1329,9 @@ grecs_json_parse ()
      Keep to zero when no symbol should be popped.  */
   int grecs_json_len = 0;
 
-  grecs_json_token = 0;
-  grecs_json_ss = grecs_json_ssa;
-  grecs_json_vs = grecs_json_vsa;
-  grecs_json_ls = grecs_json_lsa;
+  grecs_json_ssp = grecs_json_ss = grecs_json_ssa;
+  grecs_json_vsp = grecs_json_vs = grecs_json_vsa;
+  grecs_json_lsp = grecs_json_ls = grecs_json_lsa;
   grecs_json_stacksize = YYINITDEPTH;
 
   YYDPRINTF ((stderr, "Starting parse\n"));
@@ -1292,21 +1340,7 @@ grecs_json_parse ()
   grecs_json_errstatus = 0;
   grecs_json_nerrs = 0;
   grecs_json_char = YYEMPTY; /* Cause a token to be read.  */
-
-  /* Initialize stack pointers.
-     Waste one element of value and location stack
-     so that they stay on the same level as the state stack.
-     The wasted elements are never initialized.  */
-  grecs_json_ssp = grecs_json_ss;
-  grecs_json_vsp = grecs_json_vs;
-  grecs_json_lsp = grecs_json_ls;
-
-#if defined YYLTYPE_IS_TRIVIAL && YYLTYPE_IS_TRIVIAL
-  /* Initialize the default location before parsing starts.  */
-  grecs_json_lloc.first_line   = grecs_json_lloc.last_line   = 1;
-  grecs_json_lloc.first_column = grecs_json_lloc.last_column = 1;
-#endif
-
+  grecs_json_lsp[0] = grecs_json_lloc;
   goto grecs_json_setstate;
 
 /*------------------------------------------------------------.
@@ -1452,7 +1486,9 @@ grecs_json_backup:
   grecs_json_char = YYEMPTY;
 
   grecs_json_state = grecs_json_n;
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++grecs_json_vsp = grecs_json_lval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
   *++grecs_json_lsp = grecs_json_lloc;
   goto grecs_json_newstate;
 
@@ -1490,8 +1526,7 @@ grecs_json_reduce:
   switch (grecs_json_n)
     {
         case 2:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 76 "json-gram.y"
     {
   	      json_return_obj = (grecs_json_vsp[(1) - (1)].obj);
@@ -1499,8 +1534,7 @@ grecs_json_reduce:
     break;
 
   case 3:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 82 "json-gram.y"
     {
 	      (grecs_json_val.obj) = json_value_create(json_number);
@@ -1509,8 +1543,7 @@ grecs_json_reduce:
     break;
 
   case 4:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 87 "json-gram.y"
     {
 	      (grecs_json_val.obj) = json_value_create(json_string);
@@ -1519,8 +1552,7 @@ grecs_json_reduce:
     break;
 
   case 5:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 92 "json-gram.y"
     {
 	      (grecs_json_val.obj) = json_value_create(json_bool);
@@ -1529,8 +1561,7 @@ grecs_json_reduce:
     break;
 
   case 6:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 97 "json-gram.y"
     {
 	      (grecs_json_val.obj) = json_value_create(json_null);
@@ -1538,8 +1569,7 @@ grecs_json_reduce:
     break;
 
   case 8:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 102 "json-gram.y"
     {
 	      (grecs_json_val.obj) = json_value_create(json_object);
@@ -1548,8 +1578,7 @@ grecs_json_reduce:
     break;
 
   case 9:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 109 "json-gram.y"
     {
 	       (grecs_json_val.obj) = json_new_array();
@@ -1558,8 +1587,7 @@ grecs_json_reduce:
     break;
 
   case 10:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 116 "json-gram.y"
     {
 	       (grecs_json_val.list) = NULL;
@@ -1567,8 +1595,7 @@ grecs_json_reduce:
     break;
 
   case 12:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 123 "json-gram.y"
     {
 	       (grecs_json_val.list) = grecs_list_create();
@@ -1577,8 +1604,7 @@ grecs_json_reduce:
     break;
 
   case 13:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 128 "json-gram.y"
     {
  	       grecs_list_append((grecs_json_vsp[(1) - (3)].list), (grecs_json_vsp[(3) - (3)].obj));
@@ -1586,8 +1612,7 @@ grecs_json_reduce:
     break;
 
   case 14:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 134 "json-gram.y"
     {
 	      struct grecs_symtab *s;
@@ -1611,8 +1636,7 @@ grecs_json_reduce:
     break;
 
   case 15:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 156 "json-gram.y"
     {
 	       (grecs_json_val.list) = NULL;
@@ -1620,8 +1644,7 @@ grecs_json_reduce:
     break;
 
   case 17:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 163 "json-gram.y"
     {
 	       (grecs_json_val.list) = grecs_list_create();
@@ -1631,8 +1654,7 @@ grecs_json_reduce:
     break;
 
   case 18:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 169 "json-gram.y"
     {
  	       grecs_list_append((grecs_json_vsp[(1) - (3)].list), (grecs_json_vsp[(3) - (3)].p));
@@ -1640,8 +1662,7 @@ grecs_json_reduce:
     break;
 
   case 19:
-
-/* Line 1810 of yacc.c  */
+/* Line 1792 of yacc.c  */
 #line 175 "json-gram.y"
     {
 	       struct json_pair *p = grecs_malloc(sizeof(*p));
@@ -1652,9 +1673,8 @@ grecs_json_reduce:
     break;
 
 
-
-/* Line 1810 of yacc.c  */
-#line 1658 "json-gram.c"
+/* Line 1792 of yacc.c  */
+#line 1678 "json-gram.c"
       default: break;
     }
   /* User semantic actions sometimes alter grecs_json_char, and that requires
@@ -1819,7 +1839,9 @@ grecs_json_errlab1:
       YY_STACK_PRINT (grecs_json_ss, grecs_json_ssp);
     }
 
+  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++grecs_json_vsp = grecs_json_lval;
+  YY_IGNORE_MAYBE_UNINITIALIZED_END
 
   grecs_json_error_range[2] = grecs_json_lloc;
   /* Using YYLLOC is tempting, but would change the location of
@@ -1890,8 +1912,7 @@ grecs_json_return:
 }
 
 
-
-/* Line 2071 of yacc.c  */
+/* Line 2055 of yacc.c  */
 #line 182 "json-gram.y"
 
 
@@ -2243,4 +2264,3 @@ json_array_get(struct json_value *j, size_t idx, struct json_value **retval)
 	*retval = j->v.a->ov[idx];
 	return 0;
 }
-
