@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 2008-2010, 2012 Sergey Poznyakoff
+   Copyright (C) 2008-2016 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -483,8 +483,8 @@ init_suffix_index(struct dictdb *db)
 	for (i = 0; i < db->numwords; i++) {
 	    char *p = malloc(db->index[i].length + 1);
 	    if (!p) {
-		while (i-- >= 0)
-		    free(db->suf_index[i].word);
+		while (i > 0)
+		    free(db->suf_index[--i].word);
 		free(db->suf_index);
 		return 1;
 	    }
